Attribute VB_Name = "bsc_meas"
'*************************************************
'* DESCRIPTION:  Agilent E4991A Sample Program
'*
'* AUTHOR:       Agilent Technologies Japan, Ltd.
'* CREATED:      4/10/2001
'* PROGRAM NAME: bsc_meas.bas
'* REVISION:     A.01.00
'*
'*     Copyright (c) Agilent Technologies,
'*              All rights reserved.
'*
'*
'*  Customer shall have the personal, non-
'* transferable rights to use, copy or modify
'* this SAMPLE PROGRAM for Customer's internal
'* operations. Customer shall use the SAMPLE
'* PROGRAM solely and exclusively for its own
'* purpose and shall not license, lease, market
'* or distribute the SAMPLE PROGRAM or
'* modification or any part thereof.
'*
'*  Agilent Technologies shall not be liable for
'* the quality, performance or behavior of the
'* SAMPLE PROGRAM. Agilent Technologies especially
'* disclaims that the operation of the SAMPLE
'* PROGRAM shall be uninterrupted or error free.
'* This SAMPLE PROGRAM is provided AS IS.
'*
'*  AGILENT TECHNOLOGIES DISCLAIMS THE IMPLIED
'* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
'* A PARTICULAR PURPOSE.
'*
'*  Agilent Technologies shall not be liable for
'* any infringement of any patent, trademark,
'* copyright or other proprietary rights by the
'* SAMPLE PROGRAM or its use. Agilent Technologies
'* does not warrant that the SAMPLE PROGRAM is
'* free from infringements or such rights of third
'* parties. However, Agilent Technologies will not
'* knowingly infringe or deliver a software that
'* infringes the patent, trademark, copyright or
'* other proprietary right of a third party.
'*
'*************************************************
    
    Sub Main()
      ' Preparation for Using Event Procedure
    
      Dim Err As New clsErr
      Set Err.Evnt = New E4991ALib.Application
      
      ' STEP1: Preparation for a Measurement
    
      Dim buff As String
      Dim Swp_type As String
      Dim Para_a As String, Para_b As String, Para_c As String
      Dim Fmt_a As String, Fmt_b As String, Fmt_c As String, Display As String
      Dim Cal_type As String, Fixture As String, Mkr_src As String
      Dim Curr_lev As Double, Swp_start As Double, Swp_stop As Double
      Dim Freq_val As Double, Imp_val As Double
      Dim swp_count As Integer, Corr As Integer, i As Integer, nop As Integer, Reply As Integer, Result As Integer
      Dim Answer As Long
    
      nop = 201              '          Number of Points: 201
      Swp_type = "LOG"       '        Sweep Type(X-axis): LOGARITHMIC
      Swp_start = 1000000#   '           Start Frequency: 1.0 MHz
      Swp_stop = 3000000000# '            Stop Frequency: 3.0 GHz
      Curr_lev = 0.001       '      Source Current Level: 1 mA
      Para_a = "Z"           '   Measurement/     Trace1: |Z|
      Para_b = "LS"          '     Parameters     Trace2: Ls
      Para_c = "Q"           '                    Trace3: Q
      Fmt_a = "LOG"          '   Display/         Trace1: LOGARITHMIC
      Fmt_b = "LIN"          '     Format(Y-axis) Trace2: LINEAR
      Fmt_c = "LIN"          '                    Trace3: LINEAR
      swp_count = 3          '     Sweep Averaging Count: 3
      Display = "OVER"       '     Display Split/Overlay: OVERLAY
      Cal_type = "FIX"       '          Calibration Type: FIXED
      Fixture = "FXT16197A"  '              Test Fixture: 16197A
      Mkr_src = "MAX"        ' Specified Search Function: MAXIMUM
    
      Reply = Message("All the preparations for a measurement are complete?")
      If Reply <> 0 Then GoTo Prog_int
      
      ' STEP2: Specifying Measurement Conditions
    
      '   Reset the E4991A to the Default State
    
      SCPI.Output "SYST:PRES"
      buff = SCPI.Query("*OPC?")
    
      '   Specifying Sweep Conditions
    
      SCPI.Output "SWE:POIN " & CStr(nop)
      SCPI.Output "SWE:TYPE " & Swp_type
      SCPI.Output "FREQ:STAR " & CStr(Swp_start)
      SCPI.Output "FREQ:STOP " & CStr(Swp_stop)
      SCPI.Output "SOUR:CURR:MODE FIX"
      SCPI.Output "SOUR:CURR " & CStr(Curr_lev)
      SCPI.Output "TRIG:SOUR BUS"
    
      '   Specifying Measurement Parameters
    
      SCPI.Output "DISP:TRAC1 ON"
      SCPI.Output "DISP:TRAC2 ON"
      SCPI.Output "DISP:TRAC3 ON"
      SCPI.Output "CALC1:FORM " & Para_a
      SCPI.Output "CALC2:FORM " & Para_b
      SCPI.Output "CALC3:FORM " & Para_c
      SCPI.Output "DISP:TRAC1:Y:SPAC " & Fmt_a
      SCPI.Output "DISP:TRAC2:Y:SPAC " & Fmt_b
      SCPI.Output "DISP:TRAC3:Y:SPAC " & Fmt_c
      SCPI.Output "CALC:AVER:COUN " & CStr(swp_count)
      SCPI.Output "CALC:AVER ON"
      SCPI.Output "DISP:FORM " & Display
    
      ' STEP3: Calibration
    
      SCPI.Output "SENS:CORR1?"
      SCPI.Enter Corr
      If Corr = 1 Then
        Reply = Message("Do you perform a calibration?")
        If Reply <> 0 Then GoTo Cal_skip
      End If
    
      '   Initial Settings
    
      SCPI.Output "SENS:CORR1:CKIT DEF"
      SCPI.Output "SENS:CORR1:COLL:FPO " & Cal_type
    
      '   Data Measurement
    
      Result = Cal("OPEN")
      If Result <> 0 Then GoTo Prog_int
    
      Result = Cal("SHORT")
      If Result <> 0 Then GoTo Prog_int
    
      Result = Cal("LOAD")
      If Result <> 0 Then GoTo Prog_int
    
      Reply = Message("Do you want to measure a LOW-LOSS CAPACITOR?")
      If Reply = 0 Then
        Result = Cal("LOW-LOSS C")
        If Result <> 0 Then GoTo Prog_int
      End If
    
      SCPI.Output "SENS:CORR1:COLL:SAVE"
      buff = SCPI.Query("*OPC?")
      MsgBox "All cal-data measurement completion", vbOKOnly, "Calibration"
    
Cal_skip:
      
      ' STEP4: Connect the Test Fixture
      ' STEP5: Setting the Electrical Length of the Test Fixture
    
      Reply = Message("Connect the " & Fixture & " test fixture to the E4991A.")
      If Reply <> 0 Then GoTo Prog_int
      SCPI.Output "SENS:CORR2:FIXT " & Fixture
      buff = SCPI.Query("*OPC?")
    
      ' STEP6: Compensation (FIXED)
    
      ' Initial Settings
    
      SCPI.Output "SENS:CORR2:COLL:FPO " & Cal_type
    
      ' Data Measurement
    
      Result = Fixt_comp("OPEN")
      If Result <> 0 Then GoTo Prog_int
    
      Result = Fixt_comp("SHORT")
      If Result <> 0 Then GoTo Prog_int
    
      SCPI.Output "SENS:CORR2:COLL:SAVE"
      buff = SCPI.Query("*OPC?")
      MsgBox "All compen-data measurement completion", vbOKOnly, "Compensation"
    
      ' STEP7: Connect the DUT (Chip Inductor)
    
Meas_start:
      Reply = Message("Connect the DUT to electrode plate on the fixture.")
      If Reply <> 0 Then GoTo Prog_int
    
      ' STEP8: Auto Scaling & Maximum Point Search
    
      ' Performing a Single Sweep
    
      SCPI.Output "CALC:AVER:CLE"
      Answer = SingleMeasure
      If Answer = 0 Then
      MsgBox "A single sweep aborted", vbOKOnly, "Impedance measurement"
      GoTo Prog_int
      End If
    
      ' Performing an Auto-scale
    
Auto_scaling:
      SCPI.Output "DISP:TRAC1:Y:AUTO"
      SCPI.Output "DISP:TRAC2:Y:AUTO"
      SCPI.Output "DISP:TRAC3:Y:AUTO"
    
      ' Searching the Maximum Value
    
      SCPI.Output "CALC1:MARK1 ON"
      SCPI.Output "CALC1:MARK1:ACT"
      SCPI.Output "CALC1:MARK:FUNC " & Mkr_src
      SCPI.Output "CALC1:MARK:FUNC:EXEC"
      
      ' Reading a marker's value
    
      SCPI.Output "CALC1:MARK1:X?"
      SCPI.Enter Freq_val
      SCPI.Output "CALC1:MARK1:Y?"
      SCPI.Enter Imp_val
    
      ' Displaying Measurement Result
    
      Reply = Message("Frequency: " & CStr(Freq_val / 1000000#) & "[MHz]" & _
                       vbCrLf & "Impedance: " & CStr(Imp_val) & "[ohm]" & _
                       vbCrLf & vbCrLf & "Performing a measurement again?")
      If Reply = 0 Then GoTo Meas_start
      MsgBox "Program ended!", vbOKOnly, "Impedance measurement"
      GoTo Prog_end
    
Prog_int:
      MsgBox "Program interruption", vbOKOnly, "Impedance measurement"
     
Prog_end:

      Set Err.Evnt = Nothing
    
    End Sub
    
    Function Cal(Standard As String) As Integer
    
      Dim Reply As Integer
      Dim Answer As Long
    
      Reply = Message("Connect " & Standard & " standard to DUT port.")
    
      If Reply = 0 Then
        Select Case Standard
        Case "OPEN"
          Answer = CalMeasure(CalOpen)
        Case "SHORT"
          Answer = CalMeasure(CalShort)
        Case "LOAD"
          Answer = CalMeasure(CalLoad)
        Case "LOW-LOSS C"
          Answer = CalMeasure(CalLowLossC)
        End Select
        If Answer = 0 Then
          MsgBox Standard & " Calibration aborted!", vbOKOnly, "Calibration"
          Cal = -1
        Else
          Cal = 0
        End If
      Else
        Cal = -1
      End If
    
    End Function
    
    Function Fixt_comp(Standard As String) As Integer
    
      Dim Reply As Integer
      Dim Answer As Long
            
      Reply = Message("Connect " & Standard & " standard to electrode plate on the test fixture.")
    
      If Reply = 0 Then
        Select Case Standard
        Case "OPEN"
          Answer = CompenMeasure(CompenOpen)
        Case "SHORT"
          Answer = CompenMeasure(CompenShort)
        End Select
        If Answer = 0 Then
          MsgBox Standard & " Compensation aborted!", vbOKOnly, "Compensation"
          Fixt_comp = -1
        Else
          Fixt_comp = 0
        End If
      Else
        Fixt_comp = -1
      End If
    
    End Function
    
    Function Message(Mes As String) As Integer
    
      Dim Inp_char As Integer
    
      Inp_char = MsgBox(Mes, vbYesNo + vbQuestion, "Impedance measurement")
    
      If Inp_char = vbYes Then
        Message = 0
      Else
        Message = -1
      End If
    
    End Function

