Attribute VB_Name = "mdlVisa"
'*************************************************
'* DESCRIPTION:  Agilent E4991A Sample Program
'*
'* AUTHOR:       Agilent Technologies Japan, Ltd.
'* CREATED:      4/10/2001
'* PROGRAM NAME: ext_cont.bas
'* REVISION:     A.01.00
'*
'*     Copyright (c) Agilent Technologies,
'*              All rights reserved.
'*
'*
'*  Customer shall have the personal, non-
'* transferable rights to use, copy or modify
'* this SAMPLE PROGRAM for Customer's internal
'* operations. Customer shall use the SAMPLE
'* PROGRAM solely and exclusively for its own
'* purpose and shall not license, lease, market
'* or distribute the SAMPLE PROGRAM or
'* modification or any part thereof.
'*
'*  Agilent Technologies shall not be liable for
'* the quality, performance or behavior of the
'* SAMPLE PROGRAM. Agilent Technologies especially
'* disclaims that the operation of the SAMPLE
'* PROGRAM shall be uninterrupted or error free.
'* This SAMPLE PROGRAM is provided AS IS.
'*
'*  AGILENT TECHNOLOGIES DISCLAIMS THE IMPLIED
'* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
'* A PARTICULAR PURPOSE.
'*
'*  Agilent Technologies shall not be liable for
'* any infringement of any patent, trademark,
'* copyright or other proprietary rights by the
'* SAMPLE PROGRAM or its use. Agilent Technologies
'* does not warrant that the SAMPLE PROGRAM is
'* free from infringements or such rights of third
'* parties. However, Agilent Technologies will not
'* knowingly infringe or deliver a software that
'* infringes the patent, trademark, copyright or
'* other proprietary right of a third party.
'*
'*************************************************

Sub main()

    Dim status As Long          'VISA function status return code
    Dim Defrm As Long           'Session to Default Resource Manager
    Dim Dcsp As Long            'Session to instrument
    Dim Cur As Double           'Single to set current level
    Dim Res As String * 100     'String to hold results

    Cur = 0.1

    SCPI.Output "TRIG:SOUR BUS"
    
    ' Initializes the VISA system.
    status = viOpenDefaultRM(Defrm)
    If (status <> VI_SUCCESS) Then GoTo VisaErrorHandler

    ' Opens the session to the specified instrument.
    status = viOpen(Defrm, "GPIB0::5::INSTR", 0, 0, Dcsp)
    If (status <> VI_SUCCESS) Then GoTo VisaErrorHandler

    ' Asks for the instrument to turn the dc power on.
    status = viVPrintf(Dcsp, "INST P6V" & Chr$(10), 0)
    status = viVPrintf(Dcsp, "VOLT MAX" & Chr$(10), 0)
    status = viVPrintf(Dcsp, "CURR %lf" & Chr$(10), Cur)
    status = viVPrintf(Dcsp, "OUTP ON" & Chr$(10), 0)
    status = viVPrintf(Dcsp, "MEAS?" & Chr$(10), 0)
    If (status <> VI_SUCCESS) Then GoTo VisaErrorHandler
   
    ' Reads the result.
    status = viVScanf(Dcsp, "%t", Res)
    If (status <> VI_SUCCESS) Then GoTo VisaErrorHandler
   
    ' Displays the result.
    MsgBox "Result is: " & Res
    
    ' Performs a single measure.
    SingleMeasure
    
    ' Turns the dc power off.
    status = viVPrintf(Dcsp, "OUTP OFF" & Chr$(10), 0)
   
    ' Closes the resource manager session (which closes everything)
    Call viClose(Defrm)

    GoTo Prog_end

VisaErrorHandler:
    Dim VisaErr As String * 200
    Call viStatusDesc(Defrm, status, VisaErr)
    MsgBox "Error : " & VisaErr, vbExclamation
    End

Prog_end: End Sub



