Attribute VB_Name = "mkr_sear"
'*************************************************
'* DESCRIPTION:  Agilent E4991A Sample Program
'*
'* AUTHOR:       Agilent Technologies Japan, Ltd.
'* CREATED:      4/10/2001
'* PROGRAM NAME: mkr_sear.bas
'* REVISION:     A.01.00
'*
'*     Copyright (c) Agilent Technologies,
'*              All rights reserved.
'*
'*
'*  Customer shall have the personal, non-
'* transferable rights to use, copy or modify
'* this SAMPLE PROGRAM for Customer's internal
'* operations. Customer shall use the SAMPLE
'* PROGRAM solely and exclusively for its own
'* purpose and shall not license, lease, market
'* or distribute the SAMPLE PROGRAM or
'* modification or any part thereof.
'*
'*  Agilent Technologies shall not be liable for
'* the quality, performance or behavior of the
'* SAMPLE PROGRAM. Agilent Technologies especially
'* disclaims that the operation of the SAMPLE
'* PROGRAM shall be uninterrupted or error free.
'* This SAMPLE PROGRAM is provided AS IS.
'*
'*  AGILENT TECHNOLOGIES DISCLAIMS THE IMPLIED
'* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
'* A PARTICULAR PURPOSE.
'*
'*  Agilent Technologies shall not be liable for
'* any infringement of any patent, trademark,
'* copyright or other proprietary rights by the
'* SAMPLE PROGRAM or its use. Agilent Technologies
'* does not warrant that the SAMPLE PROGRAM is
'* free from infringements or such rights of third
'* parties. However, Agilent Technologies will not
'* knowingly infringe or deliver a software that
'* infringes the patent, trademark, copyright or
'* other proprietary right of a third party.
'*
'*************************************************

Sub Main()
  Dim trc1 As Integer, trc2 As Integer, mkr1 As Integer, mkr2 As Integer
  Dim sear_start As Double, sear_stop As Double
  Dim delta_x As Double, delta_y As Double
  Dim p_peak_x As Double, p_peak_y As Double
  Dim n_peak_x As Double, n_peak_y As Double
  Dim peak_found As Integer
  Dim swp_bool As Integer, beak_query As Integer, bool As Integer
  Dim msg As String
  
  trc1 = 1
  trc2 = 2
  mkr1 = 1
  mkr2 = 2
  sear_start = 100000000#
  sear_stop = 1000000000#
  delta_x = 1000000#
  delta_y = 0.1
  
  ' E4991A settings
  
  SCPI.Output "SYST:PRES"
  
  SCPI.Output "DISP:TRAC" & CStr(trc1) & " ON"
  SCPI.Output "DISP:TRAC" & CStr(trc2) & " OFF"
  SCPI.Output "CALC" & CStr(trc1) & ":FORM Z"
  SCPI.Output "DISP:TRAC" & CStr(trc1) & ":SEL"
  
  SCPI.Output "SWE:TYPE LOG"
  
  SCPI.Output "TRIG:SOUR INT"
  SCPI.Output "INIT:CONT OFF"
  SCPI.Output "ABOR"
  
  swp_bool = SCPI.Query("CALC:AVER?")
  If swp_bool = 1 Then SCPI.Output "CALC:AVER:CLE"
  
  bool = SingleMeasure
  If bool = 0 Then
    MsgBox ("Sweep Aborted")
  ElseIf bool = 1 Then
    
    SCPI.Output "DISP:TRAC" & CStr(trc1) & ":Y:AUTO"
    
    SCPI.Output "CALC" & CStr(trc1) & ":MARK:AOFF"
    SCPI.Output "CALC" & CStr(trc1) & ":MARK" & CStr(mkr1) & " ON"
    SCPI.Output "CALC" & CStr(trc1) & ":MARK" & CStr(mkr2) & " ON"
    SCPI.Output "CALC" & CStr(trc1) & ":MARK:DISC OFF"
    
    SCPI.Output "CALC" & CStr(trc1) & ":MARK:FUNC:DOM ON"
    SCPI.Output "CALC" & CStr(trc1) & ":MARK" & CStr(mkr) & ":ACT"
    SCPI.Output "CALC" & CStr(trc1) & ":MARK" & CStr(mkr) & ":X " & CStr(sear_start)
    SCPI.Output "CALC" & CStr(trc1) & ":MARK:FUNC:DOM:STAR"
    SCPI.Output "CALC" & CStr(trc1) & ":MARK" & CStr(mkr) & ":X " & CStr(sear_stop)
    SCPI.Output "CALC" & CStr(trc1) & ":MARK:FUNC:DOM:STOP"
    
    SCPI.Output "CALC" & CStr(trc1) & ":MARK:APE:EXC:X " & CStr(delta_x)
    SCPI.Output "CALC" & CStr(trc1) & ":MARK:APE:EXC:Y " & CStr(delta_y)
    
    msg = "Search range: " & CStr(sear_start / 1000000#) & "MHz - " & CStr(sear_stop / 1000000#) & "MHz"
    
    SCPI.Output "CALC" & CStr(trc1) & ":MARK" & CStr(mkr1) & ":X " & CStr(sear_start)
    SCPI.Output "CALC" & CStr(trc1) & ":MARK" & CStr(mkr1) & ":ACT"
    SCPI.Output "CALC" & CStr(trc1) & ":MARK:FUNC:EXEC PPE"
    peak_query = peak_not_found(trc1)
    If peak_query = 1 Then
      MsgBox ("Positive Peak Not Found")
    ElseIf peak_query = 0 Then
      SCPI.Output "CALC" & CStr(trc1) & ":MARK" & CStr(mkr1) & ":X?"
      SCPI.Enter p_peak_x
      SCPI.Output "CALC" & CStr(trc1) & ":MARK" & CStr(mkr1) & ":Y?"
      SCPI.Enter p_peak_y
      MsgBox (msg & vbCrLf & "Positive Peak: " & CStr(p_peak_y) & "[ohm]  @" & CStr(p_peak_x / 1000000#) & "MHz")
    End If
    
    SCPI.Output "CALC" & CStr(trc1) & ":MARK" & CStr(mkr2) & ":X " & CStr(sear_start)
    SCPI.Output "CALC" & CStr(trc1) & ":MARK" & CStr(mkr2) & ":ACT"
    SCPI.Output "CALC" & CStr(trc1) & ":MARK:FUNC:EXEC NPE"
    peak_query = peak_not_found(trc1)
    If peak_query = 1 Then
      MsgBox ("Negative Peak Not Found")
    ElseIf peak_query = 0 Then
      SCPI.Output "CALC" & CStr(trc1) & ":MARK" & CStr(mkr2) & ":X?"
      SCPI.Enter n_peak_x
      SCPI.Output "CALC" & CStr(trc1) & ":MARK" & CStr(mkr2) & ":Y?"
      SCPI.Enter n_peak_y
      MsgBox (msg & vbCrLf & "Negative Peak: " & CStr(n_peak_y) & "[ohm]  @" & CStr(n_peak_x / 1000000#) & "MHz")
    End If
  End If
  
  End
  
End Sub

Private Function peak_not_found(trc As Integer)
  Dim reg As String
  Dim div As Integer, Mo As Integer
  
  SCPI.Output "STAT:QUES:SEAR:COND?"
  SCPI.Enter reg
  
  div = Val(reg) \ 32
  Mo = Val(reg) Mod 32
  If div = 1 Then
    trc5 = 1
  ElseIf div = 0 Then
    trc5 = 0
  End If
  div = Mo \ 16
  Mo = Mo Mod 16
  If div = 1 Then
    trc4 = 1
  ElseIf div = 0 Then
    trc4 = 0
  End If
  div = Mo \ 8
  Mo = Mo Mod 8
  If div = 1 Then
    trc3 = 1
  ElseIf div = 0 Then
    trc3 = 0
  End If
  div = Mo \ 4
  Mo = Mo Mod 4
  If div = 1 Then
    trc2 = 1
  ElseIf div = 0 Then
    trc2 = 0
  End If
  div = Mo \ 2
  Mo = Mo Mod 2
  If div = 1 Then
    trc1 = 1
  ElseIf div = 0 Then
    trc1 = 0
  End If
  
  Select Case trc
  Case 1
    peak_not_found = trc1
  Case 2
    peak_not_found = trc2
  Case 3
    peak_not_found = trc3
  Case 4
    peak_not_found = trc4
  Case 5
    peak_not_found = trc5
  End Select
  
End Function


